@@ -1,22 +1,21 @@
 # ---------------------------------------------------------------------
-# Current
+# protoclass
 # ---------------------------------------------------------------------
 
 
+__version__ = "0.5.4"
+
+
 from .proto import proto, clone, chain
 
+proto = proto
+clone = clone
+chain = chain
 
-# ---------------------------------------------------------------------
-# Deprecated
-# ---------------------------------------------------------------------
 
+# XXX: deprecated in 0.5.3, removed in 1.0.0
 
 from .proto import multiclone, multichain
 
-
-# ---------------------------------------------------------------------
-# Metadata
-# ---------------------------------------------------------------------
-
-
-__version__ = "0.5.3"
+multiclone = multiclone
+multichain = multichain
